Importing data
==============

You can find the import form under `Admin → Data management → CSV import`.
Please be sure to select a matching school term (especially when importing
groups). Then select the file you want to import and a matching import
template.

.. warning::
   Please double-check if the combination of file, template, and school term
   is correct; otherwise, existing data may be corrupted!

To start the actual import, press the button `Import data`. Now you should
see a progress bar with the current import status and all errors that may occur.

Importing multiple CSV files
----------------------------

Multiple CSV files can be uploaded in one batch by putting them in a ZIP
archive.

.. note::
   For this to work, the CSV files need to exactly follow the same pattern
   and be exactly homogeneous.

Accompanying files (photos)
---------------------------

The import of photos is supported. To do this, a CSV with at least the unique
import reference and a filename needs to be placed in a ZIP archive, together
with the files to be imported.
